/******************************************************************************
 * PreferencesForMessagesDialog.java - Allow the user to manage which messages get displayed. 
 * $Id: PreferencesForMessagesDialog.java,v 1.4 2009/02/14 13:18:21 dick Exp $
 * 
 * BuckoFIBS - Backgammon by BuckoSoft
 * Copyright 2009 - Dick Balaska - BuckoSoft, Corp.
 * 
 * $Log: PreferencesForMessagesDialog.java,v $
 * Revision 1.4  2009/02/14 13:18:21  dick
 * BuckoFIBS is released under the GNU license.
 *
 * Revision 1.3  2009/01/28 19:12:57  dick
 * Move all of the debug message settings to the messages preferences dialog.
 *
 * Revision 1.2  2009/01/18 04:58:25  dick
 * The owner is a JFrame, not a JDialog.
 *
 * Revision 1.1  2009/01/09 07:16:24  dick
 * Allow the user to manage which messages get displayed.
 */

/* 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * The Original Code is BuckoFIBS, <http://www.buckosoft.com/BuckoFIBS/>.
 * The Initial Developer of the Original Code is Dick Balaska and BuckoSoft, Corp.
 * 
 */
package com.buckosoft.fibs.BuckoFIBS.gui;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.Font;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;

import javax.swing.BorderFactory;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JDialog;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.border.BevelBorder;
import javax.swing.border.EtchedBorder;

import com.buckosoft.fibs.BuckoFIBS.BFProperties;
import com.buckosoft.fibs.BuckoFIBS.CommandDispatcher;

/** Allow the user to manage which messages get displayed.
 * @author Dick Balaska
 * @since 2009/01/09
 * @version $Revision: 1.4 $ <br> $Date: 2009/02/14 13:18:21 $
 * @see <a href="http://cvs.buckosoft.com/Projects/BuckoFIBS/BuckoFIBS/src/com/buckosoft/fibs/BuckoFIBS/gui/PreferencesForMessagesDialog.java">cvs PreferencesForMessagesDialog.java</a>
 */
public class PreferencesForMessagesDialog extends JDialog {
	private static final long serialVersionUID = 1L;
	private	CommandDispatcher	commandDispatcher;  //  @jve:decl-index=0:
	private	BFProperties		properties;

	private JPanel jContentPane = null;
	private JPanel jPanelPrefs = null;
	private JLabel jLabel = null;
	private JLabel jLabel1 = null;
	private JCheckBox jCheckBoxIgnoreShouts = null;
	private JLabel jLabel2 = null;
	private JCheckBox jCheckBoxShowGameMoves = null;
	private JLabel jLabel3 = null;
	private JCheckBox jCheckBoxOtherMatchesInfo = null;
	private JLabel jLabel4 = null;
	private JCheckBox jCheckBoxLoginsAndOuts = null;
	private JPanel jPanelOkCancel = null;
	private JButton jButtonOK = null;
	private JButton jButtonCancel = null;
	private JPanel jPanelPrefsDebug = null;
	private JLabel jLabelShowAllReceivedMessages = null;
	private JCheckBox jCheckBoxShowAllReceivedMessages = null;
	private JLabel jLabelDebugLabel = null;
	private JLabel jLabelShowAllTransmittedMessages = null;
	private JCheckBox jCheckBoxShowAllTransmittedMessages = null;
	private JLabel jLabelShowUnhandledCookies = null;
	private JCheckBox jCheckBoxShowUnhandledCookies = null;
	private JLabel jLabel5 = null;
	private JCheckBox jCheckBoxStdoutNetMessages = null;

	/**
	 * This method initializes a PreferencesForMessagesDialog
	 * 
	 */
	public PreferencesForMessagesDialog() {
		super();
		initialize();
	}

	/** Create and display the preferences dialog.
	 * Just set and forget.  It's modal and manages ok and cancel on its own.
	 * @param owner Probably an instance of MainDialog
	 * @param commandDispatcher The BuckoFIBS commandDispatcher
	 */
	public PreferencesForMessagesDialog(JFrame owner, CommandDispatcher commandDispatcher) {
		super(owner, true);
		this.commandDispatcher = commandDispatcher;
		this.properties = commandDispatcher.getProperties();
		initialize();
		this.setLocationRelativeTo(owner);
		
		BFProperties props = this.commandDispatcher.getProperties();
		this.jCheckBoxIgnoreShouts.getModel().setSelected(props.isMsgIgnoreShouts());
		this.jCheckBoxShowGameMoves.getModel().setSelected(props.isMsgShowGameMoves());
		this.jCheckBoxOtherMatchesInfo.getModel().setSelected(props.isMsgOtherMatchInfo());
		this.jCheckBoxLoginsAndOuts.getModel().setSelected(props.isMsgLoginsAndOuts());

		this.jCheckBoxShowAllReceivedMessages.getModel().setSelected(props.isDisplayRecv());
		this.jCheckBoxShowAllTransmittedMessages.getModel().setSelected(props.isDisplayXmit());
		this.jCheckBoxShowUnhandledCookies.getModel().setSelected(props.isDEBUG_ShowUnhandledCookies());
		this.jCheckBoxStdoutNetMessages.getModel().setSelected(props.isStdoutNetworkMessages());
	}

	private void okButtonActionPerformed(java.awt.event.ActionEvent evt) {
		setVisible(false);
		this.properties.setMsgIgnoreShouts(this.jCheckBoxIgnoreShouts.getModel().isSelected());
		this.properties.setMsgShowGameMoves(this.jCheckBoxShowGameMoves.getModel().isSelected());
		this.properties.setMsgOtherMatchInfo(this.jCheckBoxOtherMatchesInfo.getModel().isSelected());
		this.properties.setMsgLoginsAndOuts(this.jCheckBoxLoginsAndOuts.getModel().isSelected());

		this.properties.setDisplayRecv(this.jCheckBoxShowAllReceivedMessages.getModel().isSelected());
		this.properties.setDisplayXmit(this.jCheckBoxShowAllTransmittedMessages.getModel().isSelected());
		this.properties.setDEBUG_ShowUnhandledCookies(this.jCheckBoxShowUnhandledCookies.getModel().isSelected());
		this.properties.setStdoutNetworkMessages(this.jCheckBoxStdoutNetMessages.getModel().isSelected());
		dispose();
	}

	private void cancelButtonActionPerformed(java.awt.event.ActionEvent evt) {
		setVisible(false);
		dispose();
	}

	/**
	 * This method initializes this
	 * 
	 */
	private void initialize() {
        this.setSize(new Dimension(335, 338));
        this.setTitle("Message Preferences");
        this.setContentPane(getJContentPane());
			
	}

	/**
	 * This method initializes jContentPane	
	 * 	
	 * @return javax.swing.JPanel	
	 */
	private JPanel getJContentPane() {
		if (jContentPane == null) {
			GridBagConstraints gridBagConstraints13 = new GridBagConstraints();
			gridBagConstraints13.gridx = 1;
			gridBagConstraints13.gridy = 1;
			GridBagConstraints gridBagConstraints12 = new GridBagConstraints();
			gridBagConstraints12.gridx = 1;
			gridBagConstraints12.anchor = GridBagConstraints.SOUTH;
			gridBagConstraints12.weighty = 0.2;
			gridBagConstraints12.gridy = 2;
			jLabel1 = new JLabel();
			jLabel1.setText("Ignore Shouts");
			jLabel = new JLabel();
			jLabel.setText("Settings:");
			jLabel.setForeground(new Color(102, 102, 0));
			jLabel.setFont(new Font("Dialog", Font.BOLD, 14));
			GridBagConstraints gridBagConstraints = new GridBagConstraints();
			gridBagConstraints.gridx = 1;
			gridBagConstraints.weighty = 0.2;
			gridBagConstraints.gridy = 0;
			jContentPane = new JPanel();
			jContentPane.setLayout(new GridBagLayout());
			jContentPane.setBorder(BorderFactory.createEtchedBorder(EtchedBorder.LOWERED));
			jContentPane.add(getJPanelPrefs(), gridBagConstraints);
			jContentPane.add(getJPanelOkCancel(), gridBagConstraints12);
			jContentPane.add(getJPanelPrefsDebug(), gridBagConstraints13);
		}
		return jContentPane;
	}

	/**
	 * This method initializes jPanelPrefs	
	 * 	
	 * @return javax.swing.JPanel	
	 */
	private JPanel getJPanelPrefs() {
		if (jPanelPrefs == null) {
			GridBagConstraints gridBagConstraints9 = new GridBagConstraints();
			gridBagConstraints9.gridx = 1;
			gridBagConstraints9.gridy = 4;
			GridBagConstraints gridBagConstraints8 = new GridBagConstraints();
			gridBagConstraints8.gridx = 0;
			gridBagConstraints8.anchor = GridBagConstraints.WEST;
			gridBagConstraints8.gridy = 4;
			jLabel4 = new JLabel();
			jLabel4.setText("Who is logging in and out");
			GridBagConstraints gridBagConstraints7 = new GridBagConstraints();
			gridBagConstraints7.gridx = 1;
			gridBagConstraints7.gridy = 3;
			GridBagConstraints gridBagConstraints6 = new GridBagConstraints();
			gridBagConstraints6.gridx = 0;
			gridBagConstraints6.anchor = GridBagConstraints.WEST;
			gridBagConstraints6.gridy = 3;
			jLabel3 = new JLabel();
			jLabel3.setText("Info for Other Matches");
			GridBagConstraints gridBagConstraints5 = new GridBagConstraints();
			gridBagConstraints5.gridx = 1;
			gridBagConstraints5.gridy = 2;
			GridBagConstraints gridBagConstraints4 = new GridBagConstraints();
			gridBagConstraints4.gridx = 0;
			gridBagConstraints4.anchor = GridBagConstraints.WEST;
			gridBagConstraints4.gridy = 2;
			jLabel2 = new JLabel();
			jLabel2.setText("Show Game moves (dice rolls)");
			GridBagConstraints gridBagConstraints3 = new GridBagConstraints();
			gridBagConstraints3.gridx = 1;
			gridBagConstraints3.gridy = 1;
			GridBagConstraints gridBagConstraints2 = new GridBagConstraints();
			gridBagConstraints2.gridx = 0;
			gridBagConstraints2.anchor = GridBagConstraints.WEST;
			gridBagConstraints2.gridy = 1;
			GridBagConstraints gridBagConstraints1 = new GridBagConstraints();
			gridBagConstraints1.gridx = -1;
			gridBagConstraints1.anchor = GridBagConstraints.WEST;
			gridBagConstraints1.gridy = -1;
			jPanelPrefs = new JPanel();
			jPanelPrefs.setLayout(new GridBagLayout());
			jPanelPrefs.setBorder(BorderFactory.createBevelBorder(BevelBorder.LOWERED));
			jPanelPrefs.add(jLabel, gridBagConstraints1);
			jPanelPrefs.add(jLabel1, gridBagConstraints2);
			jPanelPrefs.add(getJCheckBoxIgnoreShouts(), gridBagConstraints3);
			jPanelPrefs.add(jLabel2, gridBagConstraints4);
			jPanelPrefs.add(getJCheckBoxShowGameMoves(), gridBagConstraints5);
			jPanelPrefs.add(jLabel3, gridBagConstraints6);
			jPanelPrefs.add(getJCheckBoxOtherMatchesInfo(), gridBagConstraints7);
			jPanelPrefs.add(jLabel4, gridBagConstraints8);
			jPanelPrefs.add(getJCheckBoxLoginsAndOuts(), gridBagConstraints9);
		}
		return jPanelPrefs;
	}

	/**
	 * This method initializes jCheckBoxIgnoreShouts	
	 * 	
	 * @return javax.swing.JCheckBox	
	 */
	private JCheckBox getJCheckBoxIgnoreShouts() {
		if (jCheckBoxIgnoreShouts == null) {
			jCheckBoxIgnoreShouts = new JCheckBox();
		}
		return jCheckBoxIgnoreShouts;
	}

	/**
	 * This method initializes jCheckBoxShowGameMoves	
	 * 	
	 * @return javax.swing.JCheckBox	
	 */
	private JCheckBox getJCheckBoxShowGameMoves() {
		if (jCheckBoxShowGameMoves == null) {
			jCheckBoxShowGameMoves = new JCheckBox();
		}
		return jCheckBoxShowGameMoves;
	}

	/**
	 * This method initializes jCheckBoxOtherMatchesInfo	
	 * 	
	 * @return javax.swing.JCheckBox	
	 */
	private JCheckBox getJCheckBoxOtherMatchesInfo() {
		if (jCheckBoxOtherMatchesInfo == null) {
			jCheckBoxOtherMatchesInfo = new JCheckBox();
		}
		return jCheckBoxOtherMatchesInfo;
	}

	/**
	 * This method initializes jCheckBoxLoginsAndOuts	
	 * 	
	 * @return javax.swing.JCheckBox	
	 */
	private JCheckBox getJCheckBoxLoginsAndOuts() {
		if (jCheckBoxLoginsAndOuts == null) {
			jCheckBoxLoginsAndOuts = new JCheckBox();
		}
		return jCheckBoxLoginsAndOuts;
	}

	/**
	 * This method initializes jPanelOkCancel	
	 * 	
	 * @return javax.swing.JPanel	
	 */
	private JPanel getJPanelOkCancel() {
		if (jPanelOkCancel == null) {
			GridBagConstraints gridBagConstraints11 = new GridBagConstraints();
			gridBagConstraints11.fill = GridBagConstraints.HORIZONTAL;
			gridBagConstraints11.gridx = -1;
			gridBagConstraints11.gridy = -1;
			gridBagConstraints11.insets = new Insets(0, 15, 0, 0);
			GridBagConstraints gridBagConstraints10 = new GridBagConstraints();
			gridBagConstraints10.anchor = GridBagConstraints.EAST;
			gridBagConstraints10.insets = new Insets(0, 0, 0, 15);
			gridBagConstraints10.gridx = -1;
			gridBagConstraints10.gridy = -1;
			gridBagConstraints10.weightx = 0.1;
			gridBagConstraints10.fill = GridBagConstraints.HORIZONTAL;
			jPanelOkCancel = new JPanel();
			jPanelOkCancel.setLayout(new GridBagLayout());
			jPanelOkCancel.add(getJButtonOK(), gridBagConstraints10);
			jPanelOkCancel.add(getJButtonCancel(), gridBagConstraints11);
		}
		return jPanelOkCancel;
	}

	/**
	 * This method initializes jButtonOK	
	 * 	
	 * @return javax.swing.JButton	
	 */
	private JButton getJButtonOK() {
		if (jButtonOK == null) {
			jButtonOK = new JButton();
			jButtonOK.setText("OK");
			jButtonOK.addActionListener(new java.awt.event.ActionListener() {
				public void actionPerformed(java.awt.event.ActionEvent e) {
					okButtonActionPerformed(e);
				}
			});
		}
		return jButtonOK;
	}

	/**
	 * This method initializes jButtonCancel	
	 * 	
	 * @return javax.swing.JButton	
	 */
	private JButton getJButtonCancel() {
		if (jButtonCancel == null) {
			jButtonCancel = new JButton();
			jButtonCancel.setText("Cancel");
			jButtonCancel.addActionListener(new java.awt.event.ActionListener() {
				public void actionPerformed(java.awt.event.ActionEvent e) {
					cancelButtonActionPerformed(e);
				}
			});
		}
		return jButtonCancel;
	}

	/**
	 * This method initializes jPanelPrefsDebug	
	 * 	
	 * @return javax.swing.JPanel	
	 */
	private JPanel getJPanelPrefsDebug() {
		if (jPanelPrefsDebug == null) {
			GridBagConstraints gridBagConstraints20 = new GridBagConstraints();
			gridBagConstraints20.gridx = 1;
			gridBagConstraints20.gridy = 5;
			GridBagConstraints gridBagConstraints19 = new GridBagConstraints();
			gridBagConstraints19.anchor = GridBagConstraints.WEST;
			gridBagConstraints19.gridy = 5;
			gridBagConstraints19.gridx = 0;
			jLabel5 = new JLabel();
			jLabel5.setText("stdout Network Messages:");
			GridBagConstraints gridBagConstraints16 = new GridBagConstraints();
			gridBagConstraints16.gridx = 1;
			gridBagConstraints16.gridy = 3;
			GridBagConstraints gridBagConstraints15 = new GridBagConstraints();
			gridBagConstraints15.anchor = GridBagConstraints.WEST;
			gridBagConstraints15.gridy = 3;
			gridBagConstraints15.gridx = 0;
			jLabelShowUnhandledCookies = new JLabel();
			jLabelShowUnhandledCookies.setText("Show unhandled FIBS cookies:");
			GridBagConstraints gridBagConstraints91 = new GridBagConstraints();
			gridBagConstraints91.gridx = 1;
			gridBagConstraints91.gridy = 1;
			GridBagConstraints gridBagConstraints81 = new GridBagConstraints();
			gridBagConstraints81.insets = new Insets(0, 0, 0, 10);
			gridBagConstraints81.gridy = 1;
			gridBagConstraints81.gridx = 0;
			jLabelShowAllTransmittedMessages = new JLabel();
			jLabelShowAllTransmittedMessages.setText("Show all Transmitted network messages:");
			GridBagConstraints gridBagConstraints71 = new GridBagConstraints();
			gridBagConstraints71.anchor = GridBagConstraints.WEST;
			gridBagConstraints71.gridy = 0;
			gridBagConstraints71.gridx = 0;
			jLabelDebugLabel = new JLabel();
			jLabelDebugLabel.setFont(new Font("Dialog", Font.BOLD, 14));
			jLabelDebugLabel.setText("Debug Settings:");
			jLabelDebugLabel.setForeground(new Color(102, 102, 0));
			GridBagConstraints gridBagConstraints51 = new GridBagConstraints();
			gridBagConstraints51.gridx = -1;
			gridBagConstraints51.gridy = 2;
			GridBagConstraints gridBagConstraints41 = new GridBagConstraints();
			gridBagConstraints41.anchor = GridBagConstraints.WEST;
			gridBagConstraints41.gridy = 2;
			gridBagConstraints41.gridx = -1;
			jLabelShowAllReceivedMessages = new JLabel();
			jLabelShowAllReceivedMessages.setText("Show all received Network Messages:");
			jPanelPrefsDebug = new JPanel();
			jPanelPrefsDebug.setLayout(new GridBagLayout());
			jPanelPrefsDebug.setBorder(BorderFactory.createBevelBorder(BevelBorder.LOWERED));
			jPanelPrefsDebug.add(jLabelShowAllReceivedMessages, gridBagConstraints41);
			jPanelPrefsDebug.add(getJCheckBoxShowAllReceivedMessages(), gridBagConstraints51);
			jPanelPrefsDebug.add(jLabelDebugLabel, gridBagConstraints71);
			jPanelPrefsDebug.add(jLabelShowAllTransmittedMessages, gridBagConstraints81);
			jPanelPrefsDebug.add(getJCheckBoxShowAllTransmittedMessages(), gridBagConstraints91);
			jPanelPrefsDebug.add(jLabelShowUnhandledCookies, gridBagConstraints15);
			jPanelPrefsDebug.add(getJCheckBoxShowUnhandledCookies(), gridBagConstraints16);
			jPanelPrefsDebug.add(jLabel5, gridBagConstraints19);
			jPanelPrefsDebug.add(getJCheckBoxStdoutNetMessages(), gridBagConstraints20);
		}
		return jPanelPrefsDebug;
	}

	/**
	 * This method initializes jCheckBoxShowAllReceivedMessages	
	 * 	
	 * @return javax.swing.JCheckBox	
	 */
	private JCheckBox getJCheckBoxShowAllReceivedMessages() {
		if (jCheckBoxShowAllReceivedMessages == null) {
			jCheckBoxShowAllReceivedMessages = new JCheckBox();
		}
		return jCheckBoxShowAllReceivedMessages;
	}

	/**
	 * This method initializes jCheckBoxShowAllTransmittedMessages	
	 * 	
	 * @return javax.swing.JCheckBox	
	 */
	private JCheckBox getJCheckBoxShowAllTransmittedMessages() {
		if (jCheckBoxShowAllTransmittedMessages == null) {
			jCheckBoxShowAllTransmittedMessages = new JCheckBox();
		}
		return jCheckBoxShowAllTransmittedMessages;
	}

	/**
	 * This method initializes jCheckBoxShowUnhandledCookies	
	 * 	
	 * @return javax.swing.JCheckBox	
	 */
	private JCheckBox getJCheckBoxShowUnhandledCookies() {
		if (jCheckBoxShowUnhandledCookies == null) {
			jCheckBoxShowUnhandledCookies = new JCheckBox();
		}
		return jCheckBoxShowUnhandledCookies;
	}

	/**
	 * This method initializes jCheckBoxStdoutNetMessages	
	 * 	
	 * @return javax.swing.JCheckBox	
	 */
	private JCheckBox getJCheckBoxStdoutNetMessages() {
		if (jCheckBoxStdoutNetMessages == null) {
			jCheckBoxStdoutNetMessages = new JCheckBox();
		}
		return jCheckBoxStdoutNetMessages;
	}

}  //  @jve:decl-index=0:visual-constraint="5,7"
