/******************************************************************************
 * SystemMessagesTextPane.java - Display decorated text messages to the user.
 * $Id: SystemMessagesTextPane.java,v 1.6 2009/02/14 13:25:05 dick Exp $
 * 
 * BuckoFIBS - Backgammon by BuckoSoft
 * Copyright 2008 - Dick Balaska - BuckoSoft, Corp.
 * 
 * $Log: SystemMessagesTextPane.java,v $
 * Revision 1.6  2009/02/14 13:25:05  dick
 * BuckoFIBS is released under the GNU license.
 * Javadoc.
 *
 * Revision 1.5  2009/01/28 19:42:09  dick
 * Prettier cvs link in the javadoc.
 *
 * Revision 1.4  2008/12/11 10:00:48  dick
 * Differentiate between networkin and networkmsg, which display in different colors.
 *
 * Revision 1.3  2008/12/10 18:06:26  dick
 * Display messages with decorations.
 *
 * Revision 1.2  2008/12/09 01:52:20  dick
 * Set the font to monospaced.
 *
 * Revision 1.1  2008/03/30 05:43:29  dick
 * The window that gets system messages printed to it.
 */

/* 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * The Original Code is BuckoFIBS, <http://www.buckosoft.com/BuckoFIBS/>.
 * The Initial Developer of the Original Code is Dick Balaska and BuckoSoft, Corp.
 * 
 */
package com.buckosoft.fibs.BuckoFIBS.gui;

import java.awt.Color;

import javax.swing.JTextPane;
import javax.swing.text.BadLocationException;
import javax.swing.text.Style;
import javax.swing.text.StyleConstants;
import javax.swing.text.StyleContext;
import javax.swing.text.StyledDocument;

/** Display decorated text messages to the user.
 * @author Dick Balaska
 * @since 2008/03/30
 * @version $Revision: 1.6 $ <br> $Date: 2009/02/14 13:25:05 $
 * @see <a href="http://cvs.buckosoft.com/Projects/BuckoFIBS/BuckoFIBS/src/com/buckosoft/fibs/BuckoFIBS/gui/SystemMessagesTextPane.java">cvs SystemMessagesTextPane.java</a>
 */
public class SystemMessagesTextPane extends JTextPane {
	private static final long serialVersionUID = 1L;

	/** Regular text */
	public static final int NORMAL		= 0;
	/** monospaced, yellowish */
	public static final int NETWORKIN	= 1;
	/** monospaced, in a brownish hue */
	public static final int NETWORKOUT	= 2;
	/** monospaced */
	public static final int NETWORKMSG	= 3;
	public static final int ITALIC		= 4;
	public static final int BOLD		= 5;
	public static final int LARGE		= 6;
	public static final int DEBUG		= 7;
	/** Display text in red */
	public static final int ERROR		= 8;

	private static final int LAST		= 9;
	
	private	StyledDocument 		document;

	private	Style[] styles = new Style[LAST];
	
	/** Create a SystemMessagesTextPane
	 */
	public SystemMessagesTextPane() {
		document = this.getStyledDocument();
		addStylesToDocument(document);
		initialize();
	}

	/**
	 * This method initializes this
	 * 
	 */
	private void initialize() {
			
	}

	private void addStylesToDocument(StyledDocument doc) {
		// Initialize some styles.
		Style def = StyleContext.getDefaultStyleContext().getStyle(
				StyleContext.DEFAULT_STYLE);

		styles[NORMAL] = doc.addStyle("regular", def);

		styles[ITALIC] = doc.addStyle("italic", styles[NORMAL]);
		StyleConstants.setItalic(styles[ITALIC], true);

		styles[BOLD] = doc.addStyle("bold", styles[NORMAL]);
		StyleConstants.setBold(styles[BOLD], true);

		styles[LARGE] = doc.addStyle("large", styles[NORMAL]);
		StyleConstants.setFontSize(styles[LARGE], 16);

		styles[NETWORKIN] = doc.addStyle("fixed", styles[NORMAL]);
		StyleConstants.setFontFamily(styles[NETWORKIN], "Monospaced");
		StyleConstants.setForeground(styles[NETWORKIN], new Color(0,153,255));

		styles[NETWORKOUT] = doc.addStyle("fixed", styles[NORMAL]);
		StyleConstants.setFontFamily(styles[NETWORKOUT], "Monospaced");
		StyleConstants.setForeground(styles[NETWORKOUT], new Color(153,126,87));

		styles[NETWORKMSG] = doc.addStyle("fixed", styles[NORMAL]);
		StyleConstants.setFontFamily(styles[NETWORKMSG], "Monospaced");

		styles[DEBUG] = doc.addStyle("debug", styles[NORMAL]);
		StyleConstants.setFontFamily(styles[DEBUG], "Monospaced");
		StyleConstants.setForeground(styles[DEBUG], new Color(151,51,189));

		styles[ERROR] = doc.addStyle("fixed", styles[NORMAL]);
		StyleConstants.setFontFamily(styles[ERROR], "Monospaced");
		StyleConstants.setForeground(styles[ERROR], Color.red);

	}

	/** Append a message to the bottom of the pane in the NORMAL style
	 * @param s The message to append
	 */
	public void	appendMessage(String s) {
		try {
			this.document.insertString(this.document.getLength(), s, styles[NORMAL]);
		} catch (BadLocationException e) {
			e.printStackTrace();
		}
	}

	/** Append a message to the bottom of the pane in this style
	 * @param style The style to draw this message in.
	 * @param s The message to append
	 */
	public void	appendMessage(int style, String s) {
		if (style < 0 || style > LAST)
			style = NORMAL;
		try {
			this.document.insertString(this.document.getLength(), s, styles[style]);
		} catch (BadLocationException e) {
			e.printStackTrace();
		}
	}
}
