/******************************************************************************
 * InviterTableModel.java - The Inviter's JList Table Model
 * $Id: InviterTableModel.java,v 1.5 2009/02/24 08:06:48 dick Exp $
 * 
 * BuckoFIBS - Backgammon by BuckoSoft
 * Copyright 2008 - Dick Balaska - BuckoSoft, Corp.
 * 
 * $Log: InviterTableModel.java,v $
 * Revision 1.5  2009/02/24 08:06:48  dick
 * Add the hostName as a column.
 *
 * Revision 1.4  2009/02/14 15:46:36  dick
 * BuckoFIBS is released under the GNU license.
 *
 * Revision 1.3  2009/02/11 09:07:30  dick
 * playerChanged(Player) to update the changed player in the invter table.
 * This is in case we got invited by an unknown player, and then figured him out.
 *
 * Revision 1.2  2009/02/02 08:39:25  dick
 * Use a string for the match length, so we can say "" or "unlimited".
 *
 * Revision 1.1  2009/01/28 19:39:15  dick
 * package com.buckosoft.fibs.gui.inviterList becomes com.buckosoft.fibs.BuckoFIBS.gui.inviterList.
 *
 * Revision 1.6  2009/01/28 08:32:07  dick
 * Add removeAll to clean the list.
 * Javadoc.
 *
 * Revision 1.5  2009/01/27 19:16:43  dick
 * playerName gets a custom renderer so we can display warnings.
 *
 * Revision 1.4  2009/01/27 06:56:23  dick
 * playerchanged() and playerGone() become invited() and uninvited().
 *
 * Revision 1.3  2009/01/09 07:19:28  dick
 * Turn off debug.
 *
 * Revision 1.2  2008/12/10 18:07:20  dick
 * Inviter contains a Player, not extends it.
 *
 * Revision 1.1  2008/12/09 19:40:15  dick
 * The Inviter's JList Table Model.
 */

/* 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * The Original Code is BuckoFIBS, <http://www.buckosoft.com/BuckoFIBS/>.
 * The Initial Developer of the Original Code is Dick Balaska and BuckoSoft, Corp.
 * 
 */
package com.buckosoft.fibs.BuckoFIBS.gui.inviterList;

import java.util.LinkedList;
import java.util.ListIterator;

import javax.swing.table.AbstractTableModel;

import com.buckosoft.fibs.BuckoFIBS.gui.playerList.Column;
import com.buckosoft.fibs.domain.Player;

/** The Inviter's JList Table Model
 * @author Dick Balaska
 * @since 2008/12/08
 * @version $Revision: 1.5 $ <br> $Date: 2009/02/24 08:06:48 $
 * @see <a href="http://cvs.buckosoft.com/Projects/BuckoFIBS/BuckoFIBS/src/com/buckosoft/fibs/BuckoFIBS/gui/inviterList/InviterListPane.java">cvs InviterListPane.java</a>
 */
public class InviterTableModel extends AbstractTableModel {
	private	final static boolean DEBUG = false;
	private static final long serialVersionUID = 1L;

	public class Inviter {
		Player p;
		Inviter(Player p) {
			super();
			this.p = p;
		}
		String matchLength;
	}

	private class InviterColumns {
		private	LinkedList<Column>	columns = new LinkedList<Column>();
		
		InviterColumns() {
			columns.add(new Column("Name", 20));
			columns.add(new Column("Match", 10));
			columns.add(new Column("Rating", 10));
			columns.add(new Column("Exp", 9));
			columns.add(new Column("Host", 300));
		}

		/**
		 * @return the columns
		 */
		public LinkedList<Column> getColumns() {
			return columns;
		}

	}

	private	InviterColumns	_inviterColumns = new InviterColumns();
	private	LinkedList<Inviter>	inviters = new LinkedList<Inviter>();
	
	/** Method to add a Player to the inviter table
	 * @param player The Player that invited us
	 * @param matchLength How many games in the match
	 */
	public void invited(Player player, String matchLength) {
		ListIterator<Inviter> liter = inviters.listIterator();
		int row = -1;
		while (liter.hasNext()) {
			row++;
			Inviter p = liter.next();
			if (p.p.getName().equals(player.getName())) {
				Inviter pi = new Inviter(player);
				pi.matchLength = matchLength;
				liter.set(pi);
				this.fireTableRowsUpdated(row, row);
				if (DEBUG)
					System.out.println("inviterChanged: " + player.getName());
				return;
			}
		}
		Inviter pi = new Inviter(player);
		pi.matchLength = matchLength;	
		inviters.add(pi);
		if (DEBUG)
			System.out.println("inviterChanged: " + player.getName());
		this.fireTableRowsInserted(inviters.size()-1, inviters.size()-1);
	}

	/** Method to remove a player from the inviter table.
	 * This is called i.e. when a player starts a match with someone else, or logs out.
	 * @param playerName The name of the player to remove
	 */
	public void uninvited(String playerName) {
		ListIterator<Inviter> liter = inviters.listIterator();
		int row = -1;
		while (liter.hasNext()) {
			row++;
			Inviter p = liter.next();
			if (p.p.getName().equals(playerName)) {
				liter.remove();
				this.fireTableRowsDeleted(row, row);
			}
		}
	}
	
	/** Remove all of the inviters in the list
	 */
	public void removeAll() {
		inviters.clear();
		this.fireTableDataChanged();		
	}

	public void playerChanged(Player p) {
		Inviter i = getInviter(p.getName());
		if (i == null)
			return;
		i.p = p;
		this.fireTableDataChanged();
	}
	
	/** Return the Inviter that matches this playerName
	 * @param playerName The name to match
	 * @return the Inviter or null if not found
	 */
	public Inviter getInviter(String playerName) {
		for (Inviter p : inviters) {
			if (p.p.getName().equals(playerName))
				return(p);
		}
		return(null);
	}

	/** Add a warning to this inviter. <br>
	 * Right now, we handle "Don't join if you want to resume a saved match with x".<br>
	 * Eventually, we will add MissManners and RepBot warnings.  
	 * @param playerName The name of the questionable player
	 * @param warning The warning message to display as a tooltip.
	 */
	public void setWarning(String playerName, String warning) {
		Inviter inv = getInviter(playerName);
		if (inv != null) {
			inv.p.setBfStatus(warning);
			this.fireTableDataChanged();
		}
	}

	/* (non-Javadoc)
	 * @see javax.swing.table.TableModel#getColumnClass(int)
	 */
	public Class<?> getColumnClass(int arg0) {
		try {
			if (arg0 == 0)
				return(Class.forName("com.buckosoft.fibs.domain.Player"));
			return Class.forName("java.lang.String");
		} catch (ClassNotFoundException e) {
			System.out.println("Exception ignored...");
			e.printStackTrace();
		}
		return(null);
	}

	/* (non-Javadoc)
	 * @see javax.swing.table.TableModel#getColumnCount()
	 */
	public int getColumnCount() {
		return _inviterColumns.getColumns().size();
	}

	/* (non-Javadoc)
	 * @see javax.swing.table.TableModel#getColumnName(int)
	 */
	public String getColumnName(int arg0) {
		return _inviterColumns.getColumns().get(arg0).getName();
	}

	/* (non-Javadoc)
	 * @see javax.swing.table.TableModel#getRowCount()
	 */
	public int getRowCount() {
		return this.inviters.size();
	}

	/* (non-Javadoc)
	 * @see javax.swing.table.TableModel#getValueAt(int, int)
	 */
	public Object getValueAt(int arg0, int arg1) {
		Inviter p = inviters.get(arg0);
		switch (arg1) {
		case 0:
			return(p.p);
		
		case 1:
			return(p.matchLength);
		case 2:
			return(p.p.getRating());
		case 3:
			return(p.p.getExperience());
		case 4:
			return(p.p.getHostName());
		}
		return null;
	}

	/** All cells are not editable
	 * @see javax.swing.table.TableModel#isCellEditable(int, int)
	 */
	public boolean isCellEditable(int arg0, int arg1) {
		return false;
	}

	/* (non-Javadoc)
	 * @see javax.swing.table.TableModel#setValueAt(java.lang.Object, int, int)
	 */
	public void setValueAt(Object arg0, int arg1, int arg2) {
		// TODO Auto-generated method stub

	}

}
